bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 35. Aventiure
___________________________________________________ #### Wie Irinch erslagen wart
| ### o rief von Tenemarke der marcraue Irinch ### ich han vf ere lazen nv lange miniv dinch ### vn– han in volkers stvrmen des besten vil getan ### bringet mir min gewefne ia wil ich Hagne bestan
###### 1966 | ### Daz wil ich widerraten sprach do Hagne ### so hiez vf hoher wichen die Hvnen degne ### gespringent iwer zwene oder dri in den sal ### die send ich vngesvnde die stiegen widere zetal
###### 1967 | ### Darvmbe ichz niht enlaze sprach aber Irinch ### ich han ovch e versvochet sam sorclichiv dinch ### ia wil ich mit dem swerte eine dich bestan ### waz hilfet din vbermvot daz dv mit rede hast getan
###### 1968 | ### Do wart gewafent balde der degen Irinch ### vn– Irnvrit von Dvringen ein kvener <ivngelinch> ### vn– Hawart der starche wol mit tvsent man ### swes Irinch begvnde si woldens alle ime gestan
###### 1969 | ### Do sach der videlere ein vil groze schar ### die mit Iringe gewafent komen dar ### si trvogen vf gebvnden manigen helm gvot ### do wart der kvene Volker ein teil vil zornich gemvot
###### 1970 | ### Sehet ir vrivnt Hagne dort Iringen gan ### der ivch mit dem swerte lobete eine bestan ### wie zimet helde liegen ich vmbrisen daz ### ez gent mit im gewafent tvsent reken oder baz
###### 1971 | ### Nv heizet mich niht liegen sprach Hawartes man ### ich wil gerne leisten daz ich gelobet han ### dvrch deheine vorhte wil ichs abe lan ### swie grvlich nv si Hagne ich wil in eine bestan
###### 1972 | ### Ze fvezen bot sich Irinch magen vn– man ### daz sin eine liezen den reken bestan ### daz taten si vngerne wan in was wol bekant ### der vbermvot Hagnen vz Bvrgonden lant
###### 1973 | ### Doch bat er si so lange daz ez sit geschach ### do daz ingesinde sinen willen sach ### daz er warp nah eren do liezens in gan ### des wart von den beiden ein grimmez stritten getan
###### 1974 | ### Irinch von Tenemarchen hohe trvoch den ger [80b] ### sich tacte mit dem schilde der tiwer degne her ### do lief er vf zvo stagnen vaste fvr den sal ### do hvop sich von den degnen ein vil grozlicher schal
###### 1975 | ### Do schvzzen si die gere mit krefte von der hant ### dvrh die vesten schilte vf liehtez ir gewant ### daz die gerstangen hohe dræten dan ### do griffen zvo den swerten die zwene grimme kvene man
###### 1976 | ### Des kvenen Hagnen ellen daz waz starch groz ### doch slvog vf in Irinch daz al daz hvs erdoz ### palas vn– tvrne hullen nach ir slegen ### do kvnde niht verenden sins willen der degen
###### 1977 | ### Irinch lie Hagnen vnuerwundet stan ### zvo dem videlere gahen er began ### er wand in mvgen twingen mit sinen starken slegen ### daz kvnde wol beschermen der vil zierlich degen
###### 1978 | ### Do slvoch der videlere daz vber des schildes rant ### dræte daz gespenge von Volkers hant ### den liez er do beliben er was ein vbel man ### do lief er Gvnthern der Bvrgonden kvnich an
###### 1979 | ### Do waz ir ietweder ze strite starch genvoch ### swaz Gvnther vn– Irinch vf ein ander slvoch ### daz brahte niht von wunden vliezendes blvot ### daz behvote ir gewefne daz waz schoene vnd gvot
###### 1980 | ### Gvnthern er lie beliben vn– lief Gernoten an ### daz viwer vz den ringen hvowen er in began ### do hete von Bvrgonden der kvnich Gernot ### den kvenen Iringen erslagen næhlichen tot
###### 1981 | ### Do sprang er von dem fvrsten snel er was genvoch ### der Burgonden viere der helt vil balde slvoch ### des edeln ingesindes von Wormz vber Rin ### do enkvnde Geysehere nimmer zorner gesin
###### 1982 | ### Got weiz der Irinch sprach Geyselher daz kint ### ir mvezet mir die gelten div von iv tot sint ### gelegen an den stvnden do lief er in an ### er slvoc den Tenelender daz er mvese da bestan
###### 1983 | ### Er schoz vor sinen handen nider in daz blvot ### daz si alle wanden daz der helt gvot ### ze strite nimmer me geslvege keinen slach ### Irinch doch ane wunden hie vor Geyselhere lach
###### 1984 | ### Von des helmes <doze> vn– von des swertes klanch ### warn sin witce worden harte kranch ### daz sich der degen kvene des lebens niht versan ### daz hete mit sinen kreften der starche Geyselher getan
###### 1985 | ### Do im begvnd entwichen von hovpte der doz ### den er e da dolte von dem slage groz ### er dahte ich bin noch lebendech vn– ovch ninder wunt ### nv ist mir alerst daz ellen Geyselheres kvnt
###### 1986 | ### Er horte beidenthalben die viende stan ### wessen si div mere im were noch me getan ### ovch het er Geyselhern da bi im vernomen [81a] ### er dahte wi er solde von den vienden komen
###### 1987 | ### Wie rehte tobelichen er vz dem blvote spranch ### siner snelheit er mahte sagen danch ### do lief er vz dem hvse da er Hagnen vant ### vn– slvog im slege swinde mit siner ellenthafter hant
###### 1988 | ### Do dahte Hagne dv mvost des todes wesen ### dich envride der tievel dv kanst niht genesen ### doch wundet Irinch Hagnen dvrch den helme gvot ### daz tet der helt mit Wasken daz waz ein wafen vil gvot
###### 1989 | ### Do der herre Hagne der wunden enphant ### do erwagte im vngefvoge daz swert an siner hant ### al da mvost im entwichen der Hawartes man ### abe von der stiegen Hagne volgen im began
###### 1990 | ### Irinch der vil kvene den schilt vber hvobet swanch ### vn– were div selbe stiege drier stiegen lanch ### die wile lie in Hagne nie slahen einen slach ### hey waz roter vanken ob sime helme gelach
###### 1991 | ### Wider zvo den sinen kom Irinch wol gesvnt ### do wurden disiv mære Kriemhilde kvnt ### waz er von Trony Hagnen in strite hete getan ### des im div kvnigin vil hohe danken began
###### 1992 | ### Nv lone dir got Irinch vil mere helt gvot ### dv hast mir wol getoerstet daz herze vn– ovch den mvot ### nv sihe ich rot von blvot Hagnen sein gewant ### Kriemhilt nam im selbe den schilt vor liebe von der hant
###### 1993 | ### Ir mvget im mazen danken so sprach Hagne ### wold erz noch versvochen daz zeme degne ### koem er danne widere so wer ein kvene man ### div wunde frvmet iv kleine die ich von im enphangen han
###### 1994 | ### Daz ir von miner wunden die ringe sehet rot ### daz hat mich erreizzet vf maniges mannes tot ### ich bin erst erzvrnet wan ich lvzel schaden han ### mir hat der degen Irinch noch vil kleine getan
###### 1995 | ### Do stvont gein dem winde Irinch von Tenelant ### er kvolte sich in ringen den helm er abe gebant ### do sprachen al die lvte sin ellen were gvot ### des hete der marcraue einen rich hohen mvot
###### 1996 | ### Aber sprach do Irinch mine vriunt wiz der daz ### daz ir mich wafent schiere ich wilz versvochen baz ### ob ich mvge betwingen den vbermvoten man ### sin schilt waz verhowen einen bezzer er gewan
###### 1997 | ### Vil schiere wart der reke do gewafent baz ### einen ger vil starken nam er dvrch den haz ### da mite er aber wolde Hagnen dort bestan ### do wartet im vientliche Hagne der vil kvene man
###### 1998 | ### Sin mohte niht erbiten Hagne der degne ### er lief im hin enkegne mit schvzzen vn– slegen ### die stiegen an ein ende sin zvrnen daz waz groz ### Irinch siner sterke do vil wenich genoz
###### 1999 | ### Si slvogen dvrch die schilde daz ez lovgnen began [81b] ### von viwer roten winden der Hawartes man ### wart von Hagnen swerte krefteclich wunt ### dvrch schilt vnd helm des er wart nimmer me gesvnt
###### 2000 | ### Do der degen Irinch der wunden enpfant ### den schilt er baz do ruete vber div helmbant ### der schade in dvhte der volle den er da gewan ### sit tet im aber me des kvnich Gvnthers man
###### 2001 | ### Hagne vor sinen fvezen einen ger ligen vant ### er schoz vf Iringen den helt von Tenelant ### daz im von hovbte div stange ragte dan ### im hete der reke Hagne den grimmen ende getan
###### 2002 | ### Irinch mvost entwichen zvo den von Tenelant ### e man do dem degne den helm ab gebant ### man brach den ger von hovbte do nahte in der tot ### daz weinden sine mage des gie si werlich not
###### 2003 | ### Do kom div kvnigin vber in gegan ### den starken Iringen klagen si began ### si weinde sine wunden ez waz ir grimme leit ### do sprach vor sinen magen der kvene reke vngemeit
###### 2004 | ### Lat die klage beliben vil hetlichez wip ### waz hilfet iwer weinen ia mvoz ich minen lip ### verliesen von den wunden die ich enphangen han ### der tot wil mich niht langer iv vnd Eceln lan
###### 2005 | ### Er sprach zvo den von Dvringen vn– den von Tenelant ### die gabe sol enphahen iwer deheins hant ### von der kvniginne ir liehtez golt vil rot ### vn– bestet ir Hagnen ir mveset kiesen den tot
###### 2006 | ### Sin varwe was erblichen des todes zeichen trvoch ### Irinch der vil kvene daz waz in leit genvoch ### genesen niht enmohte der Hawartes man ### do mvos ez an ein striten von den von Tenemarke gan
###### 2007 | ### Irnvrit vn– Hawart sprvngen fvr daz gadem ### mit tvsent helden vil vngefvegen starcken ### horte man allenthalben kreftek vnd groz ### hey waz man scharfer gere zvo den Bvrgonden schoz
###### 2008 | ### Irnvrit der kvene lief an den spilman ### des er schaden grozen von siner hant gewan ### der edel videlere den lantcrauen slvoch ### dvrch einen helm veste ia waz er grimme genvoch
###### 2009 | ### Do slvoch der herre Irnvrit den kvenen spilman ### daz im mvosen bresten div ringes gespan ### vn– daz sich beschvtte div brvnne viwer rot ### doch viel der lantcraue vor dem videlere tot
###### 2010 | ### Hawart vn– Hagne zesamne warn komen ### er mohte wunder kiesen derz hete war genomen ### div swert genote vieln den heiden an der hant ### Hawart mvoste sterben von dem von Bvrgonden lant
###### 2011 | ### Do die Tenen vn– die Dvring ir herren sahen tot ### do hvop sich vor dem hvse ein vreislicher not ### e si die tvr gewunnen mit ellenthafter hant [82a] ### des wart da verhowen manich helm vn– rant
###### 2012 | ### Wichet sprach do Volker vnd lat si her in gan ### ez ist stvst vnverendet des si da habent wan ### si mvezen dar inne sterben in vil kvrzer zit ### si arnent mit dem tode daz in div kvniginne git
###### 2013 | ### Do die vbermveten komen in den sal ### vil manigem wart daz hovbet geneiget so zetal ### daz er mvost ersterben von ir swinden slegen ### wol streit der kvene Gernot sam tet ovch Geyselher der degen
###### 2014 | ### Tvsent vnd viere komen in daz hvs ### von swerten sach man bliken vil manigen swinden svs ### sit wurden doch die reken alle drinne erslagen ### man mohte michel wunder von den Bvrgonden sagen
###### 2015 | ### Darnach wart ein stille do der schal verdoz ### daz blvot allenthalben dvrch div locher vloz ### vn– da ze den rigelsteinen von den toten man ### daz heten die von Rine mit starchen ellen getan
###### 2016 | ### Do sazen aber rawen die von Bvrgonden lant ### div wafen mit den schilden si leiten von der hant ### do stvont noch vor dem hvse der kvene spilman ### er warte ob iemen wolde noch zvo in mit strite gan
###### 2017 | ### Der kvnich klagte sere sam tet ovch sin wip ### meide vn– vrowen quelten da den lip ### ich wene des daz hete der tot vf si gesworn ### des wart noch vil der reken von den gesten da verlorn

<<< Übersicht <<< vorige Seite nächste Seite >>>